| Title: | Multiscale Multifractal Analysis of Time Series Data |
|---|---|
| Description: | Multiscale multifractal analysis (MMA) (GieraĆtowski et al., 2012)<DOI:10.1103/PhysRevE.85.021915> is a time series analysis method, designed to describe scaling properties of fluctuations within the signal analyzed. The main result of this procedure is the so called Hurst surface h(q,s) , which is a dependence of the local Hurst exponent h (fluctuation scaling exponent) on the multifractal parameter q and the scale of observation s (data window width). |
| Authors: | Vishakh Padmakumar [aut, cre], Rishab Ranga [aut], Amogha Udupa [aut], Param Hanji [aut] |
| Maintainer: | Vishakh Padmakumar <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.1 |
| Built: | 2026-05-26 09:28:46 UTC |
| Source: | https://github.com/cran/TSeriesMMA |
Multiscale Multifractal Analysis of Time Series Data
mma(smin = 10, smax = 600, qmin = -5, qmax = 5, data, col = "V1", theta = -45, phi = 25)mma(smin = 10, smax = 600, qmin = -5, qmax = 5, data, col = "V1", theta = -45, phi = 25)
smin |
Minimal s scale used, when calculating Fq(s) functions family (default 10) |
smax |
Maximal s scale used, when calculating Fq(s) functions family, has to be multiple of 5 (default 600; in general should be near to N/50, where N is a time series length) |
qmin |
Minimal multifractal parameter q used (default -5) |
qmax |
Maximal cmultifractal parameter q used (deafault 5) |
data |
Time series data |
col |
The color variation of the plot |
theta |
Angle of view |
phi |
Second angle of view |
## Not run: mma(smax=30, data=timeSeriesData) ## End(Not run)## Not run: mma(smax=30, data=timeSeriesData) ## End(Not run)